@@ -1,10 +1,7 @@
 import click
-
 from great_expectations.cli import toolkit
 from great_expectations.cli.util import cli_message, cli_message_dict
-from great_expectations.core.usage_statistics.usage_statistics import (
-    send_usage_message,
-)
+from great_expectations.core.usage_statistics.usage_statistics import send_usage_message
 
 
 @click.group()
@@ -15,10 +12,10 @@ def store():
 
 @store.command(name="list")
 @click.option(
-    '--directory',
-    '-d',
+    "--directory",
+    "-d",
     default=None,
-    help="The project's great_expectations directory."
+    help="The project's great_expectations directory.",
 )
 def store_list(directory):
     """List known Stores."""
@@ -30,9 +27,7 @@ def store_list(directory):
         if len(stores) == 0:
             cli_message("No Stores found")
             send_usage_message(
-                data_context=context,
-                event="cli.store.list",
-                success=True
+                data_context=context, event="cli.store.list", success=True
             )
             return
         elif len(stores) == 1:
@@ -46,15 +41,7 @@ def store_list(directory):
             cli_message("")
             cli_message_dict(store)
 
-        send_usage_message(
-            data_context=context,
-            event="cli.store.list",
-            success=True
-        )
+        send_usage_message(data_context=context, event="cli.store.list", success=True)
     except Exception as e:
-        send_usage_message(
-            data_context=context,
-            event="cli.store.list",
-            success=False
-        )
+        send_usage_message(data_context=context, event="cli.store.list", success=False)
         raise e
